@@ -13,7 +13,7 @@ package MooX::Options;
 use strict;
 use warnings;
 
-our $VERSION = '4.022';    # VERSION
+our $VERSION = '4.023';    # VERSION
 
 use Locale::TextDomain 'MooX-Options';
 
@@ -222,7 +222,7 @@ MooX::Options - Explicit Options eXtension for Object Class
 
 =head1 VERSION
 
-version 4.022
+version 4.023
 
 =head1 DESCRIPTION
 
@@ -251,13 +251,12 @@ In myOptions.pm :
 
 In myTool.pl :
 
-  use feature 'say';
   use myOptions;
   use Path::Class;
 
   my $opt = myOptions->new_with_options;
 
-  say "Content of the file : ",
+  print "Content of the file : ",
        file($opt->show_this_file)->slurp;
 
 To use it :
