@@ -13,7 +13,7 @@ use strict;
 use warnings;
 ## no critic (ProhibitExcessComplexity)
 
-our $VERSION = '4.022';    # VERSION
+our $VERSION = '4.023';    # VERSION
 
 use MooX::Options::Descriptive;
 use Scalar::Util qw/blessed/;
@@ -258,7 +258,7 @@ sub new_with_options {
     if ( $@ =~ /^Attribute\s\((.*?)\)\sis\srequired/x ) {
         print STDERR "$1 is missing\n";
     }
-    elsif ( $@ =~ /^Missing\srequired\sarguments:\s(.*)\sat\s\(/x ) {
+    elsif ( $@ =~ /^Missing\srequired\sarguments:\s(.*)\sat\s/x ) {
         my @missing_required = split /,\s/x, $1;
         print STDERR
             join( "\n", ( map { $_ . " is missing" } @missing_required ),
@@ -487,7 +487,7 @@ MooX::Options::Role - role that is apply to your object
 
 =head1 VERSION
 
-version 4.022
+version 4.023
 
 =head1 METHODS
 
